package com.ozs.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.domain.entity.SysDept;
import com.ozs.common.utils.SecurityUtils;
import com.ozs.system.domain.SysDeptOrgan;
import com.ozs.system.mapper.SysDeptMapper;
import com.ozs.system.mapper.SysDeptOrganMapper;
import com.ozs.system.service.SysDeptOrganService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;


/**
 * 参数配部门的机关指导处 服务层实现
 *
 * @author buzy
 */
@Service
public class SysDeptOrganServiceImpl implements SysDeptOrganService {

    @Autowired
    private SysDeptOrganMapper deptOrganMapper;
    @Autowired
    private SysDeptMapper sysDeptMapper;


    @Override
    public List<SysDeptOrgan> selectList() {
        Long deptId = SecurityUtils.getDeptId();
        SysDept sysDept = sysDeptMapper.selectDeptById(deptId);
        List<Long> list = new ArrayList<>();
        list.add(deptId);
        //本级和上级
        if (!ObjectUtils.isEmpty(sysDept) && !ObjectUtils.isEmpty(sysDept.getParentId())) {
            list.add(sysDept.getParentId());
        }
        LambdaQueryWrapper<SysDeptOrgan> wrapper = new LambdaQueryWrapper<>();
        wrapper.in(SysDeptOrgan::getDeptId, list);
        List<SysDeptOrgan> organs = deptOrganMapper.selectList(wrapper);
        return organs;
    }

    @Override
    public AjaxResult selectListMap() {
        HashMap<String, List<SysDeptOrgan>> hashMap = new HashMap<>();
        Long deptId = SecurityUtils.getDeptId();
        SysDept sysDept = sysDeptMapper.selectDeptById(deptId);
        //本部门
        LambdaQueryWrapper<SysDeptOrgan> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(SysDeptOrgan::getDeptId, deptId);
        List<SysDeptOrgan> organs = deptOrganMapper.selectList(wrapper);
        hashMap.put(sysDept.getDeptName(), organs);
        //上级
        LambdaQueryWrapper<SysDeptOrgan> wrapperT = new LambdaQueryWrapper<>();
        List<SysDeptOrgan> organsT;
        if (sysDept.getParentId() != 0) {
            wrapperT.eq(SysDeptOrgan::getDeptId, sysDept.getParentId());
            organsT = deptOrganMapper.selectList(wrapperT);
            SysDept sysDeptTwo = sysDeptMapper.selectDeptById(deptId);
            hashMap.put(sysDeptTwo.getDeptName(), organsT);
        }
        return AjaxResult.success(hashMap);
    }

    @Override
    public AjaxResult insertDeptOrgan(SysDeptOrgan deptOrgan) {
        if (deptOrganMapper.insert(deptOrgan) == 1) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error("网络出小差，请稍后重试");
        }
    }

    @Override
    public AjaxResult deleteById(SysDeptOrgan deptOrgan) {
        if (deptOrganMapper.deleteById(deptOrgan.getId()) == 1) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error("网络出小差，请稍后重试");
        }
    }

}
